Error

Enum Error 

#[non_exhaustive]
pub enum Error { Xcb(Error), BadScreenNumber(i32), UnsupportedVisual(u8, VisualClass), CouldNotFindRootVisual(Visualid), ImageTooLarge(u32, u32), BadBufferSize(usize, u16, u16), Image(ImageError), }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Xcb(Error)

XCB error as a result of an X request.



BadScreenNumber(i32)

Unrecognised screen number, i.e. negative or does not match any existing screen.



UnsupportedVisual(u8, VisualClass)

Display server uses unsupported visual. This library supports 24- or 32-bit TrueColour visual only.



CouldNotFindRootVisual(Visualid)

Failed to locate visual that matches the root visual.



ImageTooLarge(u32, u32)

Image too large. Image dimensions must fit 16-bit unsigned integer.



BadBufferSize(usize, u16, u16)

The image buffer size does not match image dimensions.



Image(ImageError)