Display

Struct Display 

pub struct Display { /* private fields */ }
Handler for an X11 connection.

Implementations

Source

impl Display

pub fn open() -> Result<Self>

Opens connection to X11 display.

pub fn from_xcb(conn: Connection, screen_num: i32) -> Result<Self>

Constructs the object from existing XCB connection.

pub fn into_xcb(self) -> (Connection, i32)

Consumes the object and returns the underlying XCB connection. Returns a (conn, screen_num) pair just as xcb::Connection::connect.

pub fn conn(&self) -> &Connection

Returns reference to the XCB connection.

pub fn default_screen_num(&self) -> i32

Returns the default screen number.

pub fn default_screen(&self) -> Result<&Screen, BadScreenNumber>

Returns the default screen.

pub fn monitors(&self) -> Result<Vec<Monitor>>

Returns list of active monitors.

Uses RandR extensions to query the dimensions of the monitors. Requires RandR extension version 1.5 or newer to work.

pub fn root_pixmap(&self) -> Result<RootPixmap<'_>>

Returns a representation of the root window’s background pixmap.

The object can be used to draw on the pixmap before finally setting it as the root window’s pixmap. It’s dimensions and depth matches the default screen’s.